```{include} _templates/nav.html
```

# savepagenow

A simple Python wrapper and command-line interface for archive.org’s [“Save Page Now”](https://archive.org/web) capturing service

```{toctree}
:maxdepth: 1
:name: mastertoc

install
python
cli
useragent
exceptions
```

## Links

- Documentation: [palewi.re/docs/savepagenow/](https://palewi.re/docs/savepagenow/)
- Code: [github.com/palewire/savepagenow](https://github.com/palewire/savepagenow)
- Issues: [github.com/palewire/savepagenow/issues](https://github.com/palewire/savepagenow/issues)
- Packaging: [pypi.org/project/savepagenow](https://pypi.org/project/savepagenow)
